import { IResource, Resource } from 'aws-cdk-lib';
import * as codeartifact from 'aws-cdk-lib/aws-codeartifact';
import * as iam from 'aws-cdk-lib/aws-iam';
import * as kms from 'aws-cdk-lib/aws-kms';
import { Construct } from 'constructs';
import * as repository from './repository';
export interface IDomain extends IResource {
    /**
     * The ARN of the domain.
     *
     * @attribute
     */
    readonly domainArn: string;
    /**
     * The name of the domain.
     *
     * @attribute
     */
    readonly domainName: string;
    /**
     * The account that owns the domain.
     *
     * @attribute
     */
    readonly domainOwner?: string;
    /**
     * The key used to encrypt the domain.
     *
     * @attribute
     */
    readonly domainEncryptionKey?: string;
    /**
     * The key used to encrypt the domain.
     *
     * @attribute
     */
    readonly encryptionKey?: kms.IKey;
    /**
     * Grant read permissions to the given principal on this domain.
     */
    grantRead(grantee: iam.IGrantable): iam.Grant;
    /**
     * Grant write permissions to the given principal on this domain.
     */
    grantWrite(grantee: iam.IGrantable): iam.Grant;
    /**
     * Grant read and write permissions to the given principal on this domain.
     */
    grantReadWrite(grantee: iam.IGrantable): iam.Grant;
    /**
     * Add a repository to this domain.
     */
    addRepository(id: string, props: repository.RepositoryOptions): repository.IRepository;
}
/**
 * The base domain class
 */
declare abstract class DomainBase extends Resource implements IDomain {
    abstract domainArn: string;
    abstract domainName: string;
    abstract domainOwner?: string;
    abstract domainEncryptionKey?: string;
    abstract encryptionKey?: kms.IKey;
    readActions: string[];
    writeActions: string[];
    private grant;
    grantRead(principal: iam.IGrantable): iam.Grant;
    grantWrite(principal: iam.IGrantable): iam.Grant;
    grantReadWrite(principal: iam.IGrantable): iam.Grant;
    addRepository(id: string, props: repository.RepositoryOptions): repository.IRepository;
}
/**
 * Attributes of a domain
 */
export interface DomainAttributes {
    /**
     * The ARN of the domain.
     */
    readonly domainArn?: string;
    /**
     * The name of the domain.
     */
    readonly domainName?: string;
    /**
     * The account that owns the domain.
     */
    readonly domainOwner?: string;
    /**
     * The key used to encrypt the domain.
     */
    readonly domainEncryptionKey?: string;
    /**
     * The key used to encrypt the domain.
     */
    readonly encryptionKey?: kms.IKey;
}
/**
 * The properties for a new domain.
 */
export interface DomainProps {
    /**
     * A string that specifies the name of the requested domain.
     */
    readonly name: string;
    /**
     * The key used to encrypt the domain.
     *
     * @default - An AWS managed key is created automatically.
     */
    readonly encryptionKey?: kms.IKey;
    /**
     * The document that defines the resource policy that is set on a domain.
     *
     * @default - No policy is set. The account will have full permissions to the domain.
     */
    readonly permissionsPolicyDocument?: iam.PolicyDocument;
}
/**
 * A CodeArtifact domain.
 */
export declare class Domain extends DomainBase {
    /**
     * Reference an existing domain by its ARN
     */
    static fromDomainArn(scope: Construct, id: string, domainArn: string): IDomain;
    /**
     * Import an existing domain given its attributes. Either `domainArn` or `domainName` is required.
     */
    static fromDomainAttributes(scope: Construct, id: string, attrs: DomainAttributes): IDomain;
    /**
     * The underlying CfnDomain resource.
     */
    readonly cfnDomain: codeartifact.CfnDomain;
    /**
     * The ARN of the domain.
     */
    readonly domainArn: string;
    /**
     * The name of the domain.
     */
    readonly domainName: string;
    /**
     * The account that owns the domain.
     */
    readonly domainOwner?: string;
    /**
     * The key used to encrypt the domain.
     */
    readonly domainEncryptionKey?: string;
    /**
     * The key used to encrypt the domain.
     */
    readonly encryptionKey?: kms.IKey;
    constructor(scope: Construct, id: string, props: DomainProps);
}
export {};
