import { IResource, Resource } from 'aws-cdk-lib';
import * as codeartifact from 'aws-cdk-lib/aws-codeartifact';
import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import * as domain from './domain';
/**
 * CodeArtifact supports an external connection to the following public repositories.
 *
 * @see https://docs.aws.amazon.com/codeartifact/latest/ug/external-connection.html#supported-public-repositories
 */
export declare enum ExternalConnection {
    /**
     * npm public registry
     */
    NPM = "public:npmjs",
    /**
     * NuGet Gallery
     */
    DOTNET_NUGETORG = "public:nuget-org",
    /**
     * Python Package Index
     */
    PYTHON_PYPI = "public:pypi",
    /**
     * Maven Central
     */
    MAVEN_CENTRAL = "public:maven-central",
    /**
     * Google Android repository
     */
    MAVEN_GOOGLEANDROID = "public:maven-googleandroid",
    /**
     * Gradle plugins repository
     */
    MAVEN_GRADLEPLUGINS = "public:maven-gradleplugins",
    /**
     * CommonsWare Android repository
     */
    MAVEN_COMMONSWARE = "public:maven-commonsware"
}
/**
 * This interface represents a CodeArtifact Repository resource
 *
 * @experimental
 */
export interface IRepository extends IResource {
    /**
     * The ARN of the repository.
     *
     * @attribute
     */
    readonly repositoryArn: string;
    /**
     * The name of the repository.
     *
     * @attribute
     */
    readonly repositoryName: string;
    /**
     * The name of the domain that contains the repository.
     *
     * @attribute
     */
    readonly repositoryDomainName?: string;
    /**
     * The account that owns the domain that contains the repository.
     */
    readonly repositoryDomainOwner?: string;
    /**
     * The domain that contains the repository.
     */
    readonly domain: domain.IDomain;
    /**
     * Grant read permissions to the given principal on this repository.
     */
    grantRead(grantee: iam.IGrantable): iam.Grant;
    /**
     * Grant write permissions to the given principal on this respository.
     */
    grantWrite(grantee: iam.IGrantable): iam.Grant;
    /**
     * Grant read and write permissions to the given principal on this repository.
     */
    grantReadWrite(grantee: iam.IGrantable): iam.Grant;
}
/**
 * The base respository class
 */
declare abstract class RepositoryBase extends Resource implements IRepository {
    abstract readonly repositoryArn: string;
    abstract readonly repositoryName: string;
    abstract readonly repositoryDomainName?: string;
    abstract readonly repositoryDomainOwner?: string;
    abstract readonly domain: domain.IDomain;
    readActions: string[];
    writeActions: string[];
    private grant;
    grantRead(principal: iam.IGrantable): iam.Grant;
    grantWrite(principal: iam.IGrantable): iam.Grant;
    grantReadWrite(principal: iam.IGrantable): iam.Grant;
}
/**
 * Attributes of a repository
 */
export interface RepositoryAttributes {
    /**
     * The ARN of the repository
     */
    readonly repositoryArn?: string;
    /**
     * The name of the repository
     */
    readonly repositoryName?: string;
    /**
     * The name of the domain that contains the repository
     */
    readonly repositoryDomainName?: string;
    /**
     * The account that owns the domain that contains the repository
     */
    readonly repositoryDomainOwner?: string;
    /**
     * The domain that contains the repository
     */
    readonly domain?: domain.IDomain;
}
/**
 * The options for creating a new repository
 */
export interface RepositoryOptions {
    /**
     * The name of the repository
     */
    readonly name: string;
    /**
     * The description of the repository
     *
     * @defualt - No description
     */
    readonly description?: string;
    /**
     * An array of external connections associated with the repository
     *
     * @see https://docs.aws.amazon.com/codeartifact/latest/ug/external-connection.html
     */
    readonly externalConnections?: ExternalConnection[];
    /**
      * The document that defines the permissions policy for the repository
      */
    readonly permissionsPolicyDocument?: iam.PolicyDocument;
    /**
      * An array of upstream repositories associated with the repository
      *
      * @see https://docs.aws.amazon.com/codeartifact/latest/ug/repos-upstream.html
      */
    readonly upstreams?: IRepository[];
}
/**
 * The properties of a CodeArtifact Repository
 */
export interface RepositoryProps extends RepositoryOptions {
    /**
     * The domain that the repository will be created in
     */
    readonly domain: domain.IDomain;
}
/**
 * A CodeArtifact domain.
 */
export declare class Repository extends RepositoryBase {
    /**
     * Reference an existing repository by its ARN
     */
    static fromRepositoryArn(scope: Construct, id: string, repositoryArn: string): IRepository;
    /**
     * Reference an existing repository by its attributes
     */
    static fromRepositoryAttributes(scope: Construct, id: string, attrs: RepositoryAttributes): IRepository;
    /**
     * The underlying CfnRepository.
     */
    readonly cfnRepository: codeartifact.CfnRepository;
    /**
     * The ARN of the repository
     */
    readonly repositoryArn: string;
    /**
     * The name of the repository
     */
    readonly repositoryName: string;
    /**
     * The name of the domain that contains the repository
     */
    readonly repositoryDomainName?: string;
    /**
     * The account that owns the domain that contains the repository
     */
    readonly repositoryDomainOwner?: string;
    /**
     * The name of the repository domain
     */
    readonly domain: domain.IDomain;
    constructor(scope: Construct, id: string, props: RepositoryProps);
}
export {};
